"use strict";
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.isUnexpected = isUnexpected;
const responseMap = {
    "GET /operations": ["200"],
    "GET /operations/{operationId}": ["200"],
    "GET /info": ["200"],
    "GET /documentModels/{modelId}/analyzeResults/{resultId}": ["200"],
    "DELETE /documentModels/{modelId}/analyzeResults/{resultId}": ["204"],
    "GET /documentModels/{modelId}/analyzeResults/{resultId}/pdf": ["200"],
    "GET /documentModels/{modelId}/analyzeResults/{resultId}/figures/{figureId}": ["200"],
    "GET /documentModels/{modelId}:analyze": ["200", "202"],
    "POST /documentModels/{modelId}:analyze": ["202"],
    "GET /documentModels/{modelId}/analyzeBatchResults/{resultId}": ["200"],
    "DELETE /documentModels/{modelId}/analyzeBatchResults/{resultId}": ["204"],
    "GET /documentModels/{modelId}:analyzeBatch": ["200", "202"],
    "POST /documentModels/{modelId}:analyzeBatch": ["202"],
    "GET /documentModels/{modelId}/analyzeBatchResults": ["200"],
    "GET /documentModels/{modelId}": ["200"],
    "DELETE /documentModels/{modelId}": ["204"],
    "GET /documentModels:build": ["200", "202"],
    "POST /documentModels:build": ["202"],
    "GET /documentModels:compose": ["200", "202"],
    "POST /documentModels:compose": ["202"],
    "POST /documentModels:authorizeCopy": ["200"],
    "GET /documentModels/{modelId}:copyTo": ["200", "202"],
    "POST /documentModels/{modelId}:copyTo": ["202"],
    "GET /documentModels": ["200"],
    "GET /documentClassifiers:build": ["200", "202"],
    "POST /documentClassifiers:build": ["202"],
    "GET /documentClassifiers": ["200"],
    "GET /documentClassifiers/{classifierId}": ["200"],
    "DELETE /documentClassifiers/{classifierId}": ["204"],
    "GET /documentClassifiers/{classifierId}:analyze": ["200", "202"],
    "POST /documentClassifiers/{classifierId}:analyze": ["202"],
    "GET /documentClassifiers/{classifierId}/analyzeResults/{resultId}": ["200"],
    "POST /documentClassifiers:authorizeCopy": ["200"],
    "GET /documentClassifiers/{classifierId}:copyTo": ["200", "202"],
    "POST /documentClassifiers/{classifierId}:copyTo": ["202"],
};
function isUnexpected(response) {
    const lroOriginal = response.headers["x-ms-original-url"];
    const url = new URL(lroOriginal !== null && lroOriginal !== void 0 ? lroOriginal : response.request.url);
    const method = response.request.method;
    let pathDetails = responseMap[`${method} ${url.pathname}`];
    if (!pathDetails) {
        pathDetails = getParametrizedPathSuccess(method, url.pathname);
    }
    return !pathDetails.includes(response.status);
}
function getParametrizedPathSuccess(method, path) {
    var _a, _b, _c, _d;
    const pathParts = path.split("/");
    // Traverse list to match the longest candidate
    // matchedLen: the length of candidate path
    // matchedValue: the matched status code array
    let matchedLen = -1, matchedValue = [];
    // Iterate the responseMap to find a match
    for (const [key, value] of Object.entries(responseMap)) {
        // Extracting the path from the map key which is in format
        // GET /path/foo
        if (!key.startsWith(method)) {
            continue;
        }
        const candidatePath = getPathFromMapKey(key);
        // Get each part of the url path
        const candidateParts = candidatePath.split("/");
        // track if we have found a match to return the values found.
        let found = true;
        for (let i = candidateParts.length - 1, j = pathParts.length - 1; i >= 1 && j >= 1; i--, j--) {
            if (((_a = candidateParts[i]) === null || _a === void 0 ? void 0 : _a.startsWith("{")) && ((_b = candidateParts[i]) === null || _b === void 0 ? void 0 : _b.indexOf("}")) !== -1) {
                const start = candidateParts[i].indexOf("}") + 1, end = (_c = candidateParts[i]) === null || _c === void 0 ? void 0 : _c.length;
                // If the current part of the candidate is a "template" part
                // Try to use the suffix of pattern to match the path
                // {guid} ==> $
                // {guid}:export ==> :export$
                const isMatched = new RegExp(`${(_d = candidateParts[i]) === null || _d === void 0 ? void 0 : _d.slice(start, end)}`).test(pathParts[j] || "");
                if (!isMatched) {
                    found = false;
                    break;
                }
                continue;
            }
            // If the candidate part is not a template and
            // the parts don't match mark the candidate as not found
            // to move on with the next candidate path.
            if (candidateParts[i] !== pathParts[j]) {
                found = false;
                break;
            }
        }
        // We finished evaluating the current candidate parts
        // Update the matched value if and only if we found the longer pattern
        if (found && candidatePath.length > matchedLen) {
            matchedLen = candidatePath.length;
            matchedValue = value;
        }
    }
    return matchedValue;
}
function getPathFromMapKey(mapKey) {
    const pathStart = mapKey.indexOf("/");
    return mapKey.slice(pathStart);
}
//# sourceMappingURL=isUnexpected.js.map